@@ -44,7 +44,7 @@ class cryptoWallet():
 
         args:
             dates           list of datetime objects where balances are sampled
-            currency        string of currency symbol of desired output
+            currency        string of currency symbol of desired output XX
 
         note that timestamps on the ethereum blockchain are UNIX timstamps
 
@@ -165,6 +165,23 @@ class cryptoWallet():
 
         return transactions, interacted_blocks
 
+    def get_asset_balances(self, dates):
+        """ try to get all asset balances in wallet """
+
+        all_balances_df = pd.DataFrame()
+        merge_dfs = list()
+
+        # for each type of balance add to list and merge to all balances - can add in future
+        eth_balances_df = self.get_eth_balances(dates)
+        merge_dfs.append(eth_balances_df)
+
+        for df in merge_dfs:
+            if not df.empty:
+                all_balances_df = pd.concat([all_balances_df, df])
+        all_balances_df = all_balances_df.fillna(0)
+
+        return all_balances_df
+
 
 def __main__():
     # wallet = cryptoWallet(addy='0x68e6D61EDB3fb8b564E9Ae196cFa59FBda01d5A4')
@@ -179,7 +196,7 @@ def __main__():
         data_str.append(datepair[1])
 
     sample_dates = pd.date_range(start=start_date, end=end_date, freq='M')
-    balances = wallet.get_eth_balances(dates=sample_dates)
+    balances = wallet.get_asset_balances(dates=sample_dates)
     for balance in balances:
         print(balance)
     print(wallet.eth_txns)
